==> glom-1.23.3.tar.xz: glom-1.23.3/glom/onlineglom_strings.cc <==
/* Glom
 *
 * Copyright (C) 2001-2010 Murray Cumming
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301 USA.
 */

#include <glibmm/i18n.h>

// These strings are not actually used by Glom.
// I am putting them here so that GNOME's translators can translate them
// without dealing with the awkward (not gettext) system here:
// http://www.murrayc.com/blog/permalink/2012/01/27/online-glom-more-translation/
// murrayc

const char* online_glom_search = _("Search");
const char* online_glom_backToList = _("Back to List");
const char* online_glom_details = _("Details");
const char* online_glom_open = _("Open");
const char* online_glom_reports = _("Reports");
const char* online_glom_generating_report = _("Generating the report...");
const char* online_glom_login_login = _("Login");
const char* online_glom_login_enter = _("Enter the PostgreSQL username and password.");
const char* online_glom_login_username = _("Username");
const char* online_glom_login_password = _("Password");
const char* online_glom_login_logout = _("Log Out");
const char* online_glom_login_cancel = _("Cancel");
const char* online_glom_login_wrong = _("The username or password are not correct.");
const char* online_glom_login_needs_https = _("Login seems to be necessary, but will not be attempted. This site is not being served via HTTPS, which is required for secure login. Please contact your system administrator.");

==> glom-1.23.4.tar.xz: glom-1.23.4/glom/onlineglom_strings.cc <==
/* Glom
 *
 * Copyright (C) 2001-2010 Murray Cumming
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301 USA.
 */

#include <glibmm/i18n.h>

// These strings are not actually used by Glom.
// I am putting them here so that GNOME's translators can translate them
// without dealing with the awkward (not gettext) system here:
// http://www.murrayc.com/blog/permalink/2012/01/27/online-glom-more-translation/
// murrayc

const char* online_glom_search = _("Search");
const char* online_glom_backToList = _("Back to List");
const char* online_glom_details = _("Details");
const char* online_glom_open = _("Open");
const char* online_glom_reports = _("Reports");
const char* online_glom_generating_report = _("Generating the report...");
const char* online_glom_login_login = _("Login");
const char* online_glom_login_enter = _("Enter the username and password.");
const char* online_glom_login_username = _("Username");
const char* online_glom_login_password = _("Password");
const char* online_glom_login_logout = _("Log Out");
const char* online_glom_login_cancel = _("Cancel");
const char* online_glom_login_wrong = _("The username or password are not correct.");
const char* online_glom_login_needs_https = _("Login seems to be necessary, but will not be attempted. This site is not being served via HTTPS, which is required for secure login. Please contact your system administrator.");
